package codelab.modules.motormodule;

import codelab.CodeLab;
import codelab.AbstractModule;

import java.util.Map;

public class MotorModule extends AbstractModule {

	private MotorSimulator simulator;
	public CodeLab codelab;

	/*
		The setSystem(DataTableInterface) method establishes cross-references between a simulator and a DataTable
		Enables the DataTable to retrieve properties of the simulator to be displayed with getPropKey() and getPropVal()
		Enables the DataTable to request a property update with updateValues()
		If not invoked => no DataTable displayed (do not add addButton("DATA") to the Toolbar)
		
		La méthode setSystem(DataTableInterface) établit des références croisées entre un simulateur et une DataTable
		Permet à la DataTable de récupérer des propriétés du simulateur à afficher avec getPropKey() et getPropVal()
		Permet à la DataTable de demander une mise-à-jour des propriétés avec updateValues()
		Si pas invoqué => pas de DataTable affichée (ne pas mettre de addButton("DATA") dans la Toolbar)
	*/
	
	///////////////////////////////////////////////////
	// Constructor
	///////////////////////////////////////////////////

	public MotorModule(CodeLab codelab) {
		super(codelab);
		this.codelab = codelab;
		loadProperties("lang.properties");
		setTitle(getLangProperty("title"));
		setToolbar(new MotorToolbar(this));
		simulator = new MotorSimulator(this);
		setComponent(simulator); // Le composant à placer
		setSystem(simulator); // Explications ci-dessus
	}
	
	///////////////////////////////////////////////////
	// AbstractModule methods to implement
	///////////////////////////////////////////////////

	public void init() {
	}
	public void exit() {
	}

	public void start() {
		simulator.start();
	}

	public void stop() {
		simulator.stop();
	}

	public void reset() {
		simulator.reset();
	}

	///////////////////////////////////////////////////
	// Instruction handler
	///////////////////////////////////////////////////

	public String handleRequest(Map<String, String> params) {
		String cmd = params.get("cmd");
		int port, power;
		switch (cmd) {

			case "motorOn":
				port = Integer.valueOf(params.get("port"));
				power = Integer.valueOf(params.get("power"));
				return String.valueOf(simulator.motorOn(port, power));

			case "motorOff":
				port = Integer.valueOf(params.get("port"));
				return String.valueOf(simulator.motorOff(port));

			case "motorRotationCount":
				port = Integer.valueOf(params.get("port"));
				return String.valueOf(simulator.motorRotationCount(port));

			case "resetMotorRotationCount":
				port = Integer.valueOf(params.get("port"));
				return String.valueOf(simulator.resetMotorRotationCount(port));

			default:
				return unknownCommandError(cmd);
		}
	}
}
